summaryrefslogtreecommitdiffstats
path: root/include/widgets
diff options
context:
space:
mode:
authorDave Davenport <qball@gmpclient.org>2017-06-09 09:18:17 +0200
committerDave Davenport <qball@gmpclient.org>2017-06-09 09:18:17 +0200
commit067544120f950039557a04f1ba06ec6870bd1088 (patch)
tree4b4eb49b9f63587ce3e4ab7e3e39847f30e61327 /include/widgets
parentb99f86f34195cefe0bcb287f2f5b4469a83d03c9 (diff)
Make function declaration match function prototype.
- Extra NULL check.
Diffstat (limited to 'include/widgets')
-rw-r--r--include/widgets/widget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/widgets/widget.h b/include/widgets/widget.h
index 322ef64d..9807aada 100644
--- a/include/widgets/widget.h
+++ b/include/widgets/widget.h
@@ -272,11 +272,11 @@ WidgetTriggerActionResult widget_trigger_action ( widget *wid, guint action, gin
/**
* @param wid The widget handle
* @param cb The widget trigger action callback
* @param udata the user data to pass to callback
*
* Override the widget trigger action handler on widget.
*/
-void widget_set_trigger_action_handler ( widget *wid, widget_trigger_action_cb cb, void *udata );
+void widget_set_trigger_action_handler ( widget *wid, widget_trigger_action_cb cb, void *cb_data );
/**
* @param wid The widget handle
@@ -272,11 +272,11 @@ WidgetTriggerActionResult widget_trigger_action ( widget *wid, guint action, gin
* @param wid The widget handle
* @param cb The widget trigger action callback
- * @param udata the user data to pass to callback
+ * @param cb_data the user data to pass to callback
*
* Override the widget trigger action handler on widget.